@@ -62,7 +62,9 @@ class Freebox(IPlugin):
 					# séparation de rs['idx'], nombre  
 					# search position '|' dans rs['idx']	
 					# 'http://hd2.freebox.fr/pub/remote_control?code=35782633&key=%s' % (rs))
-					for rx in range (1, int(rs['idx_sec'])): 				
+					for rx in range (1, int(rs['idx_sec'])):
+						log.msg("idx  :  %s" % (int(rs['idx_sec']))
+						log.msg("idx  :  %s" % (rs['idx']))
 						resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
 						log.msg("resp  :  %s" % (resp))
 				else:
